package info.aspirecn.iov.sjjh.supplier10000057.action;

import info.aspirecn.iov.sjjh.commons.lang.ChannelTypeHandleResponseObject;
import info.aspirecn.iov.sjjh.commons.lang.Constant;
import info.aspirecn.iov.sjjh.supplier10000057.constant.CommonConstant;
import info.aspirecn.iov.sjjh.supplier10000057.service.AuthorizationService;
import info.aspirecn.rdc.aspirecloud.node.except.utils.ErrorUtils;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.extern.slf4j.Slf4j;
import org.apache.tomcat.util.codec.binary.Base64;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestHeader;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;

import javax.servlet.http.HttpServletRequest;

/**
 * @author xusonglin
 * @version V1.0
 **/
@RestController
@Slf4j
public class AuthorizationAction {
    @Autowired
    AuthorizationService authorizationService;

    @ApiOperation(value = "获取定位对象", notes = "")
    @PostMapping(value = "/getLocationUser.do")
    public ChannelTypeHandleResponseObject getLocationUser(
            @ApiParam(value = "通道ID") @RequestHeader(name = "channelId") String channelId,
            @ApiParam(value = "超时时间,单位：毫秒", example = "10000") @RequestParam(name = "outTime", required = true) int outTime,
            @ApiParam(value = "请求参数JSON串") @RequestParam(name = "customBody", required = true) String customBody) {
        HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
                .getRequest();

        //调用service
        ChannelTypeHandleResponseObject ret = authorizationService.getLocationUser(request, customBody, outTime);

        //把接口参数、调用结果和是否收费放入访问日志中
        if (ret.getCode() != Constant.SUCCESS) {
            request.setAttribute(CommonConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_ERROR_CODE);
        } else {
            request.setAttribute(CommonConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_SUCCESS_CODE);
        }
        request.setAttribute(CommonConstant.Charge_Log_Key, ret.getIsCharge());

        try {
            request.setAttribute(Constant.CHANNEL_LOG_QUERY,
                    Base64.encodeBase64String(customBody.getBytes(CommonConstant.PARA_ENCODE)));

        } catch (Exception ex) {
            ErrorUtils.captureException(ex);
            log.error("getLocationUser.encodeBase64String.Exception=", ex);
        }

        request.setAttribute(Constant.CHANNEL_TYPE_KEY, Constant.CHANNEL_TYPE_SYNC);
        return ret;
    }

    @ApiOperation(value = "创建定位对象", notes = "")
    @PostMapping(value = "/createLocationUser.do")
    public ChannelTypeHandleResponseObject createLocationUser(
            @ApiParam(value = "通道ID") @RequestHeader(name = "channelId") String channelId,
            @ApiParam(value = "超时时间,单位：毫秒", example = "10000") @RequestParam(name = "outTime", required = true) int outTime,
            @ApiParam(value = "请求参数JSON串") @RequestParam(name = "customBody", required = true) String customBody) {
        HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
                .getRequest();

        //调用service
        ChannelTypeHandleResponseObject ret = authorizationService.createLocationUser(request, customBody, outTime);

        //把接口参数、调用结果和是否收费放入访问日志中
        if (ret.getCode() != Constant.SUCCESS) {
            request.setAttribute(CommonConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_ERROR_CODE);
        } else {
            request.setAttribute(CommonConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_SUCCESS_CODE);
        }
        request.setAttribute(CommonConstant.Charge_Log_Key, ret.getIsCharge());

        try {
            request.setAttribute(Constant.CHANNEL_LOG_QUERY,
                    Base64.encodeBase64String(customBody.getBytes(CommonConstant.PARA_ENCODE)));

        } catch (Exception ex) {
            ErrorUtils.captureException(ex);
            log.error("createLocationUser.encodeBase64String.Exception=", ex);
        }

        request.setAttribute(Constant.CHANNEL_TYPE_KEY, Constant.CHANNEL_TYPE_SYNC);
        return ret;
    }

    @ApiOperation(value = "删除定位对象", notes = "")
    @PostMapping(value = "/deleteLocationUser.do")
    public ChannelTypeHandleResponseObject deleteLocationUser(
            @ApiParam(value = "通道ID") @RequestHeader(name = "channelId") String channelId,
            @ApiParam(value = "超时时间,单位：毫秒", example = "10000") @RequestParam(name = "outTime", required = true) int outTime,
            @ApiParam(value = "请求参数JSON串") @RequestParam(name = "customBody", required = true) String customBody) {
        HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
                .getRequest();

        //调用service
        ChannelTypeHandleResponseObject ret = authorizationService.deleteLocationUser(request, customBody, outTime);

        //把接口参数、调用结果和是否收费放入访问日志中
        if (ret.getCode() != Constant.SUCCESS) {
            request.setAttribute(CommonConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_ERROR_CODE);
        } else {
            request.setAttribute(CommonConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_SUCCESS_CODE);
        }
        request.setAttribute(CommonConstant.Charge_Log_Key, ret.getIsCharge());

        try {
            request.setAttribute(Constant.CHANNEL_LOG_QUERY,
                    Base64.encodeBase64String(customBody.getBytes(CommonConstant.PARA_ENCODE)));

        } catch (Exception ex) {
            ErrorUtils.captureException(ex);
            log.error("createLocationUser.encodeBase64String.Exception=", ex);
        }

        request.setAttribute(Constant.CHANNEL_TYPE_KEY, Constant.CHANNEL_TYPE_SYNC);
        return ret;
    }

    @ApiOperation(value = "发送短信", notes = "")
    @PostMapping(value = "/sendMsg.do")
    public ChannelTypeHandleResponseObject sendMsg(
            @ApiParam(value = "通道ID") @RequestHeader(name = "channelId") String channelId,
            @ApiParam(value = "超时时间,单位：毫秒", example = "10000") @RequestParam(name = "outTime", required = true) int outTime,
            @ApiParam(value = "请求参数JSON串") @RequestParam(name = "customBody", required = true) String customBody) {
        HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
                .getRequest();

        //调用service
        ChannelTypeHandleResponseObject ret = authorizationService.sendMessage(request, customBody, outTime);

        //把接口参数、调用结果和是否收费放入访问日志中
        if (ret.getCode() != Constant.SUCCESS) {
            request.setAttribute(CommonConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_ERROR_CODE);
        } else {
            request.setAttribute(CommonConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_SUCCESS_CODE);
        }
        request.setAttribute(CommonConstant.Charge_Log_Key, ret.getIsCharge());

        try {
            request.setAttribute(Constant.CHANNEL_LOG_QUERY,
                    Base64.encodeBase64String(customBody.getBytes(CommonConstant.PARA_ENCODE)));

        } catch (Exception ex) {
            ErrorUtils.captureException(ex);
            log.error("sendMsg.encodeBase64String.Exception=", ex);
        }

        request.setAttribute(Constant.CHANNEL_TYPE_KEY, Constant.CHANNEL_TYPE_SYNC);
        return ret;
    }

    @ApiOperation(value = "同意授权", notes = "")
    @PostMapping(value = "/agreeAuth.do")
    public ChannelTypeHandleResponseObject agreeAuth(
            @ApiParam(value = "通道ID") @RequestHeader(name = "channelId") String channelId,
            @ApiParam(value = "超时时间,单位：毫秒", example = "10000") @RequestParam(name = "outTime", required = true) int outTime,
            @ApiParam(value = "请求参数JSON串") @RequestParam(name = "customBody", required = true) String customBody) {
        HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
                .getRequest();

        //调用service
        ChannelTypeHandleResponseObject ret = authorizationService.agreeAuth(request, customBody, outTime);

        //把接口参数、调用结果和是否收费放入访问日志中
        if (ret.getCode() != Constant.SUCCESS) {
            request.setAttribute(CommonConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_ERROR_CODE);
        } else {
            request.setAttribute(CommonConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_SUCCESS_CODE);
        }
        request.setAttribute(CommonConstant.Charge_Log_Key, ret.getIsCharge());

        try {
            request.setAttribute(Constant.CHANNEL_LOG_QUERY,
                    Base64.encodeBase64String(customBody.getBytes(CommonConstant.PARA_ENCODE)));

        } catch (Exception ex) {
            ErrorUtils.captureException(ex);
            log.error("agreeAuth.encodeBase64String.Exception=", ex);
        }

        request.setAttribute(Constant.CHANNEL_TYPE_KEY, Constant.CHANNEL_TYPE_SYNC);
        return ret;
    }

    @ApiOperation(value = "取消授权", notes = "")
    @PostMapping(value = "/cancelAuth.do")
    public ChannelTypeHandleResponseObject cancelAuth(
            @ApiParam(value = "通道ID") @RequestHeader(name = "channelId") String channelId,
            @ApiParam(value = "超时时间,单位：毫秒", example = "10000") @RequestParam(name = "outTime", required = true) int outTime,
            @ApiParam(value = "请求参数JSON串") @RequestParam(name = "customBody", required = true) String customBody) {
        HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
                .getRequest();

        //调用service
        ChannelTypeHandleResponseObject ret = authorizationService.cancelAuth(request, customBody, outTime);

        //把接口参数、调用结果和是否收费放入访问日志中
        if (ret.getCode() != Constant.SUCCESS) {
            request.setAttribute(CommonConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_ERROR_CODE);
        } else {
            request.setAttribute(CommonConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_SUCCESS_CODE);
        }
        request.setAttribute(CommonConstant.Charge_Log_Key, ret.getIsCharge());

        try {
            request.setAttribute(Constant.CHANNEL_LOG_QUERY,
                    Base64.encodeBase64String(customBody.getBytes(CommonConstant.PARA_ENCODE)));

        } catch (Exception ex) {
            ErrorUtils.captureException(ex);
            log.error("cancelAuth.encodeBase64String.Exception=", ex);
        }

        request.setAttribute(Constant.CHANNEL_TYPE_KEY, Constant.CHANNEL_TYPE_SYNC);
        return ret;
    }
}
