package info.aspirecn.iov.sjjh.supplier10000057.action;

import info.aspirecn.iov.sjjh.commons.lang.ChannelTypeHandleResponseObject;
import info.aspirecn.iov.sjjh.commons.lang.Constant;
import info.aspirecn.iov.sjjh.supplier10000057.constant.CommonConstant;
import info.aspirecn.iov.sjjh.supplier10000057.service.HistoryLocationService;
import info.aspirecn.rdc.aspirecloud.node.except.utils.ErrorUtils;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.extern.slf4j.Slf4j;
import org.apache.tomcat.util.codec.binary.Base64;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestHeader;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;

import javax.servlet.http.HttpServletRequest;

/**
 * @author xusonglin
 * @version V1.0
 **/
@RestController
@Slf4j
public class HistoryLocationAction {
    @Autowired
    HistoryLocationService historyLocationService;

    @ApiOperation(value = "获取轨迹任务", notes = "")
    @PostMapping(value = "/getHistoryLocationTask.do")
    public ChannelTypeHandleResponseObject getLocationUser(
            @ApiParam(value = "通道ID") @RequestHeader(name = "channelId") String channelId,
            @ApiParam(value = "超时时间,单位：毫秒", example = "10000") @RequestParam(name = "outTime", required = true) int outTime,
            @ApiParam(value = "请求参数JSON串") @RequestParam(name = "customBody", required = true) String customBody) {
        HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
                .getRequest();

        //调用service
        ChannelTypeHandleResponseObject ret = historyLocationService.getHistoryLocationTask(request, customBody, outTime);

        //把接口参数、调用结果和是否收费放入访问日志中
        if (ret.getCode() != Constant.SUCCESS) {
            request.setAttribute(CommonConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_ERROR_CODE);
        } else {
            request.setAttribute(CommonConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_SUCCESS_CODE);
        }
        request.setAttribute(CommonConstant.Charge_Log_Key, ret.getIsCharge());

        try {
            request.setAttribute(Constant.CHANNEL_LOG_QUERY,
                    Base64.encodeBase64String(customBody.getBytes(CommonConstant.PARA_ENCODE)));

        } catch (Exception ex) {
            ErrorUtils.captureException(ex);
            log.error("getHistoryLocationTask.encodeBase64String.Exception=", ex);
        }

        request.setAttribute(Constant.CHANNEL_TYPE_KEY, Constant.CHANNEL_TYPE_SYNC);
        return ret;
    }

    @ApiOperation(value = "创建轨迹任务", notes = "")
    @PostMapping(value = "/createHistoryLocationTask.do")
    public ChannelTypeHandleResponseObject createHistoryLocationTask(
            @ApiParam(value = "通道ID") @RequestHeader(name = "channelId") String channelId,
            @ApiParam(value = "超时时间,单位：毫秒", example = "10000") @RequestParam(name = "outTime", required = true) int outTime,
            @ApiParam(value = "请求参数JSON串") @RequestParam(name = "customBody", required = true) String customBody) {
        HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
                .getRequest();

        //调用service
        ChannelTypeHandleResponseObject ret = historyLocationService.createHistoryLocationTask(request, customBody, outTime);

        //把接口参数、调用结果和是否收费放入访问日志中
        if (ret.getCode() != Constant.SUCCESS) {
            request.setAttribute(CommonConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_ERROR_CODE);
        } else {
            request.setAttribute(CommonConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_SUCCESS_CODE);
        }
        request.setAttribute(CommonConstant.Charge_Log_Key, ret.getIsCharge());

        try {
            request.setAttribute(Constant.CHANNEL_LOG_QUERY,
                    Base64.encodeBase64String(customBody.getBytes(CommonConstant.PARA_ENCODE)));

        } catch (Exception ex) {
            ErrorUtils.captureException(ex);
            log.error("createHistoryLocationTask.encodeBase64String.Exception=", ex);
        }

        request.setAttribute(Constant.CHANNEL_TYPE_KEY, Constant.CHANNEL_TYPE_SYNC);
        return ret;
    }

    @ApiOperation(value = "删除轨迹任务", notes = "")
    @PostMapping(value = "/deleteHistoryLocationTask.do")
    public ChannelTypeHandleResponseObject deleteHistoryLocationTask(
            @ApiParam(value = "通道ID") @RequestHeader(name = "channelId") String channelId,
            @ApiParam(value = "超时时间,单位：毫秒", example = "10000") @RequestParam(name = "outTime", required = true) int outTime,
            @ApiParam(value = "请求参数JSON串") @RequestParam(name = "customBody", required = true) String customBody) {
        HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
                .getRequest();

        //调用service
        ChannelTypeHandleResponseObject ret = historyLocationService.deleteHistoryLocationTask(request, customBody, outTime);

        //把接口参数、调用结果和是否收费放入访问日志中
        if (ret.getCode() != Constant.SUCCESS) {
            request.setAttribute(CommonConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_ERROR_CODE);
        } else {
            request.setAttribute(CommonConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_SUCCESS_CODE);
        }
        request.setAttribute(CommonConstant.Charge_Log_Key, ret.getIsCharge());

        try {
            request.setAttribute(Constant.CHANNEL_LOG_QUERY,
                    Base64.encodeBase64String(customBody.getBytes(CommonConstant.PARA_ENCODE)));

        } catch (Exception ex) {
            ErrorUtils.captureException(ex);
            log.error("deleteHistoryLocationTask.encodeBase64String.Exception=", ex);
        }

        request.setAttribute(Constant.CHANNEL_TYPE_KEY, Constant.CHANNEL_TYPE_SYNC);
        return ret;
    }

    @ApiOperation(value = "轨迹任务状态更新", notes = "")
    @PostMapping(value = "/updateHistoryLocationTask.do")
    public ChannelTypeHandleResponseObject updateHistoryLocationTask(
            @ApiParam(value = "通道ID") @RequestHeader(name = "channelId") String channelId,
            @ApiParam(value = "超时时间,单位：毫秒", example = "10000") @RequestParam(name = "outTime", required = true) int outTime,
            @ApiParam(value = "请求参数JSON串") @RequestParam(name = "customBody", required = true) String customBody) {
        HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
                .getRequest();

        //调用service
        ChannelTypeHandleResponseObject ret = historyLocationService.updateHistoryLocationTask(request, customBody, outTime);

        //把接口参数、调用结果和是否收费放入访问日志中
        if (ret.getCode() != Constant.SUCCESS) {
            request.setAttribute(CommonConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_ERROR_CODE);
        } else {
            request.setAttribute(CommonConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_SUCCESS_CODE);
        }
        request.setAttribute(CommonConstant.Charge_Log_Key, ret.getIsCharge());

        try {
            request.setAttribute(Constant.CHANNEL_LOG_QUERY,
                    Base64.encodeBase64String(customBody.getBytes(CommonConstant.PARA_ENCODE)));

        } catch (Exception ex) {
            ErrorUtils.captureException(ex);
            log.error("updateHistoryLocationTask.encodeBase64String.Exception=", ex);
        }

        request.setAttribute(Constant.CHANNEL_TYPE_KEY, Constant.CHANNEL_TYPE_SYNC);
        return ret;
    }

    @ApiOperation(value = "历史轨迹查询", notes = "")
    @PostMapping(value = "/historyLocationQuery.do")
    public ChannelTypeHandleResponseObject historyLocationQuery(
            @ApiParam(value = "通道ID") @RequestHeader(name = "channelId") String channelId,
            @ApiParam(value = "超时时间,单位：毫秒", example = "10000") @RequestParam(name = "outTime", required = true) int outTime,
            @ApiParam(value = "请求参数JSON串") @RequestParam(name = "customBody", required = true) String customBody) {
        HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
                .getRequest();

        //调用service
        ChannelTypeHandleResponseObject ret = historyLocationService.historyLocationQuery(request, customBody, outTime);

        //把接口参数、调用结果和是否收费放入访问日志中
        if (ret.getCode() != Constant.SUCCESS) {
            request.setAttribute(CommonConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_ERROR_CODE);
        } else {
            request.setAttribute(CommonConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_SUCCESS_CODE);
        }
        request.setAttribute(CommonConstant.Charge_Log_Key, ret.getIsCharge());

        try {
            request.setAttribute(Constant.CHANNEL_LOG_QUERY,
                    Base64.encodeBase64String(customBody.getBytes(CommonConstant.PARA_ENCODE)));

        } catch (Exception ex) {
            ErrorUtils.captureException(ex);
            log.error("historyLocationQuery.encodeBase64String.Exception=", ex);
        }

        request.setAttribute(Constant.CHANNEL_TYPE_KEY, Constant.CHANNEL_TYPE_SYNC);
        return ret;
    }
}
