package info.aspirecn.iov.sjjh.supplier10000057.service.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import info.aspirecn.iov.sjjh.commons.lang.ChannelTypeHandleResponseObject;
import info.aspirecn.iov.sjjh.commons.lang.Constant;
import info.aspirecn.iov.sjjh.commons.lang.PatternTools;
import info.aspirecn.iov.sjjh.supplier10000057.config.SupplierConfig;
import info.aspirecn.iov.sjjh.supplier10000057.constant.CommonConstant;
import info.aspirecn.iov.sjjh.supplier10000057.model.*;
import info.aspirecn.iov.sjjh.supplier10000057.service.HistoryLocationService;
import info.aspirecn.iov.sjjh.supplier10000057.service.TokenService;
import info.aspirecn.iov.sjjh.supplier10000057.util.OkHttpUtil;
import info.aspirecn.iov.sjjh.supplier10000057.util.UnicodeUtil;
import info.aspirecn.rdc.aspirecloud.node.except.utils.ErrorUtils;
import lombok.extern.slf4j.Slf4j;
import okhttp3.FormBody;
import okhttp3.RequestBody;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import java.io.IOException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Set;
import java.util.regex.Pattern;

/**
 * @author xusonglin
 * @version V1.0
 **/
@Service
@Slf4j
public class HistoryLocationServiceImpl implements HistoryLocationService {
    @Autowired
    SupplierConfig supplierConfig;
    @Autowired
    StringRedisTemplate stringRedisTemplate;
    @Autowired
    TokenService tokenService;

    @Override
    public ChannelTypeHandleResponseObject getHistoryLocationTask(HttpServletRequest request, String customBody, int outTime) {
        ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
        ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
        String upstreamCode = "" + Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        if (outTime <= CommonConstant.PARA_ZERO) {
            outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
        }
        log.info("supplier10000057.getHistoryLocationTask---customBody={},outTime={}", customBody, outTime);
        GetHistoryLocationTaskRequestObject requestObject = JSON.toJavaObject(JSON.parseObject(customBody),
                GetHistoryLocationTaskRequestObject.class);
        log.info("supplier10000057.getHistoryLocationTask---requestObject={}", requestObject);
        // 参数校验
        if (!validateRequestParams(ret, requestObject)) {
            ret.setCode(Constant.SUCCESS);
            request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
            return ret;
        }
        // 拼接请求
        StringBuffer urlStringBuffer = new StringBuffer();
        urlStringBuffer.append(supplierConfig.getUrl());
        urlStringBuffer.append(supplierConfig.getHistoryLocationTaskPath());
        urlStringBuffer.append("?name=").append(requestObject.getName());
        if (requestObject.getPage() != null) {
            urlStringBuffer.append("&page=").append(requestObject.getPage());
        }
        if (requestObject.getLimit() != null) {
            urlStringBuffer.append("&limit=").append(requestObject.getLimit());
        }
        String token = stringRedisTemplate.boundValueOps(CommonConstant.REDIS_KEY_LOCATION_TOKEN).get();
        if (StringUtils.isBlank(token)) {
            token = tokenService.getAuthToken();
        }
        token = "JWT " + token;
        // 请求数据源
        String responseContext = "";
        try {
            responseContext = OkHttpUtil.doGet(urlStringBuffer.toString(), outTime, token);
            log.info("supplier10000057-getHistoryLocationTask-responseContext:{}", UnicodeUtil.unicodeToString(responseContext));
        } catch (IOException ioe) {
            log.info("supplier10000057.getHistoryLocationTask接口-SocketTimeoutException：", ioe);
            ErrorUtils.captureException(ioe);
            ret.setCode(Constant.REQUEST_TIMEOUT);
            return ret;
        }

        // 解析返回结果
        OriginalCommonResponseObject responseObject = JSON.toJavaObject(JSON.parseObject(responseContext),
                OriginalCommonResponseObject.class);
        ret.setIsCharge(Constant.IS_NOT_CHARGE);
        if (responseObject != null) {
            ret.setCode(Constant.SUCCESS);
            upstreamCode = responseObject.getCode();
            if (responseObject.getCode().equals(CommonConstant.REQUEST_SUCCESS)) {
                JSONObject result = new JSONObject();
                result.put("count", responseObject.getCount());
                result.put("data", responseObject.getData());
                ret.setResultBody(result);
                ret.setResultCode(Constant.JK_RETURN_CODE_1192);
                ret.setResultDesc(CommonConstant.SUCCESS_MESSAGE);
            } else {
                ret.setResultCode(Constant.JK_RETURN_CODE_1193);
                ret.setResultBody(responseObject.getMsg());
                ret.setResultDesc(Constant.OTHER_ERROR);
            }
        } else {
            ret.setCode(Constant.FAIL);
        }
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        return ret;
    }

    @Override
    public ChannelTypeHandleResponseObject createHistoryLocationTask(HttpServletRequest request, String customBody, int outTime) {
        ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
        ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
        String upstreamCode = "" + Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        if (outTime <= CommonConstant.PARA_ZERO) {
            outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
        }
        log.info("supplier10000057.createHistoryLocationTask---customBody={},outTime={}", customBody, outTime);
        CreateHistoryLocationTaskRequestObject requestObject = JSON.toJavaObject(JSON.parseObject(customBody),
                CreateHistoryLocationTaskRequestObject.class);
        log.info("supplier10000057.createHistoryLocationTask---requestObject={}", requestObject);
        // 参数校验
        if (!validateRequestParams(ret, requestObject)) {
            ret.setCode(Constant.SUCCESS);
            request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
            return ret;
        }
        String url = supplierConfig.getUrl() + supplierConfig.getHistoryLocationTaskPath();

        String token = stringRedisTemplate.boundValueOps(CommonConstant.REDIS_KEY_LOCATION_TOKEN).get();
        if (StringUtils.isBlank(token)) {
            token = tokenService.getAuthToken();
        }
        token = "JWT " + token;
        // 请求数据源
        String responseContext = "";
        try {
            JSONArray mobileArray = new JSONArray();
            mobileArray.add(requestObject.getMobile());
            RequestBody requestBody = new FormBody.Builder()
                    .add("name", requestObject.getName())
                    .add("tel", JSON.toJSONString(mobileArray).replace("\"", ""))
                    .add("r_type", requestObject.getType())
                    .add("start_end", requestObject.getStartTime() + "~" + requestObject.getEndTime())
                    .add("timespan", requestObject.getTimespan())
                    .build();
            responseContext = OkHttpUtil.doPost(url, requestBody, outTime, token);
            log.info("supplier10000057-createHistoryLocationTask-responseContext:{}", UnicodeUtil.unicodeToString(responseContext));
        } catch (IOException ioe) {
            log.info("supplier10000057.createHistoryLocationTask接口-SocketTimeoutException：", ioe);
            ErrorUtils.captureException(ioe);
            ret.setCode(Constant.REQUEST_TIMEOUT);
            return ret;
        }

        // 解析返回结果
        OriginalCommonResponseObject responseObject = JSON.toJavaObject(JSON.parseObject(responseContext),
                OriginalCommonResponseObject.class);
        ret.setIsCharge(Constant.IS_NOT_CHARGE);
        if (responseObject != null) {
            ret.setCode(Constant.SUCCESS);
            upstreamCode = responseObject.getCode();
            if (responseObject.getCode().equals(CommonConstant.REQUEST_SUCCESS)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_1192);
                ret.setResultBody(Constant.RETURN_MESSAGE_139);
                ret.setResultDesc(Constant.RETURN_MESSAGE_139);
                ret.setIsCharge(Constant.IS_CHARGE);
            } else {
                ret.setResultCode(Constant.JK_RETURN_CODE_1193);
                ret.setResultBody(responseObject.getMsg());
                ret.setResultDesc(Constant.RETURN_MESSAGE_140);
            }
        } else {
            ret.setCode(Constant.FAIL);
        }
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        return ret;
    }

    @Override
    public ChannelTypeHandleResponseObject deleteHistoryLocationTask(HttpServletRequest request, String customBody, int outTime) {
        ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
        ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
        String upstreamCode = "" + Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        if (outTime <= CommonConstant.PARA_ZERO) {
            outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
        }
        log.info("supplier10000057.deleteHistoryLocationTask---customBody={},outTime={}", customBody, outTime);
        DeleteHistoryLocationTaskRequestObject requestObject = JSON.toJavaObject(JSON.parseObject(customBody),
                DeleteHistoryLocationTaskRequestObject.class);
        log.info("supplier10000057.deleteHistoryLocationTask---requestObject={}", requestObject);
        // 参数校验
        if (!validateRequestParams(ret, requestObject)) {
            ret.setCode(Constant.SUCCESS);
            request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
            return ret;
        }
        String url = supplierConfig.getUrl() + supplierConfig.getHistoryLocationTaskPath();

        String token = stringRedisTemplate.boundValueOps(CommonConstant.REDIS_KEY_LOCATION_TOKEN).get();
        if (StringUtils.isBlank(token)) {
            token = tokenService.getAuthToken();
        }
        token = "JWT " + token;
        // 请求数据源
        String responseContext = "";
        try {
            JSONObject requestParam = new JSONObject();
            requestParam.put("tid", requestObject.getTid());
            responseContext = OkHttpUtil.doDelete(url, requestParam.toJSONString(), outTime, token);
            log.info("supplier10000057-deleteHistoryLocationTask-responseContext:{}", UnicodeUtil.unicodeToString(responseContext));
        } catch (IOException ioe) {
            log.info("supplier10000057.deleteHistoryLocationTask接口-SocketTimeoutException：", ioe);
            ErrorUtils.captureException(ioe);
            ret.setCode(Constant.REQUEST_TIMEOUT);
            return ret;
        }

        // 解析返回结果
        OriginalCommonResponseObject responseObject = JSON.toJavaObject(JSON.parseObject(responseContext),
                OriginalCommonResponseObject.class);
        ret.setIsCharge(Constant.IS_NOT_CHARGE);
        if (responseObject != null) {
            ret.setCode(Constant.SUCCESS);
            upstreamCode = responseObject.getCode();
            if (responseObject.getCode().equals(CommonConstant.REQUEST_SUCCESS)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_1192);
                ret.setResultBody(Constant.RETURN_MESSAGE_139);
                ret.setResultDesc(Constant.RETURN_MESSAGE_139);
            } else {
                ret.setResultCode(Constant.JK_RETURN_CODE_1193);
                ret.setResultBody(responseObject.getMsg());
                ret.setResultDesc(Constant.RETURN_MESSAGE_140);
            }
        } else {
            ret.setCode(Constant.FAIL);
        }
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        return ret;
    }

    @Override
    public ChannelTypeHandleResponseObject updateHistoryLocationTask(HttpServletRequest request, String customBody, int outTime) {
        ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
        ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
        String upstreamCode = "" + Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        if (outTime <= CommonConstant.PARA_ZERO) {
            outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
        }
        log.info("supplier10000057.updateHistoryLocationTask---customBody={},outTime={}", customBody, outTime);
        UpdateHistoryLocationTaskRequestObject requestObject = JSON.toJavaObject(JSON.parseObject(customBody),
                UpdateHistoryLocationTaskRequestObject.class);
        log.info("supplier10000057.updateHistoryLocationTask---requestObject={}", requestObject);
        // 参数校验
        if (!validateRequestParams(ret, requestObject)) {
            ret.setCode(Constant.SUCCESS);
            request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
            return ret;
        }
        String url = supplierConfig.getUrl() + supplierConfig.getHistoryLocationTaskPath();

        String token = stringRedisTemplate.boundValueOps(CommonConstant.REDIS_KEY_LOCATION_TOKEN).get();
        if (StringUtils.isBlank(token)) {
            token = tokenService.getAuthToken();
        }
        token = "JWT " + token;
        // 请求数据源
        String responseContext = "";
        try {
            JSONObject requestParam = new JSONObject();
            requestParam.put("tid", requestObject.getTid());
            requestParam.put("status", requestObject.getStatus());
            requestParam.put("atype", "status");
            responseContext = OkHttpUtil.doPut(url, requestParam.toJSONString(), outTime, token);
            log.info("supplier10000057-updateHistoryLocationTask-responseContext:{}", UnicodeUtil.unicodeToString(responseContext));
        } catch (IOException ioe) {
            log.info("supplier10000057.updateHistoryLocationTask接口-SocketTimeoutException：", ioe);
            ErrorUtils.captureException(ioe);
            ret.setCode(Constant.REQUEST_TIMEOUT);
            return ret;
        }

        // 解析返回结果
        OriginalCommonResponseObject responseObject = JSON.toJavaObject(JSON.parseObject(responseContext),
                OriginalCommonResponseObject.class);
        ret.setIsCharge(Constant.IS_NOT_CHARGE);
        if (responseObject != null) {
            ret.setCode(Constant.SUCCESS);
            upstreamCode = responseObject.getCode();
            if (responseObject.getCode().equals(CommonConstant.REQUEST_SUCCESS)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_1192);
                ret.setResultBody(Constant.RETURN_MESSAGE_139);
                ret.setResultDesc(Constant.RETURN_MESSAGE_139);
            } else {
                ret.setResultCode(Constant.JK_RETURN_CODE_1193);
                ret.setResultBody(responseObject.getMsg());
                ret.setResultDesc(Constant.RETURN_MESSAGE_140);
            }
        } else {
            ret.setCode(Constant.FAIL);
        }
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        return ret;
    }

    @Override
    public ChannelTypeHandleResponseObject historyLocationQuery(HttpServletRequest request, String customBody, int outTime) {
        ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
        ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
        String upstreamCode = "" + Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        if (outTime <= CommonConstant.PARA_ZERO) {
            outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
        }
        log.info("supplier10000057.historyLocationQuery---customBody={},outTime={}", customBody, outTime);
        HistoryLocationQueryRequestObject requestObject = JSON.toJavaObject(JSON.parseObject(customBody),
                HistoryLocationQueryRequestObject.class);
        log.info("supplier10000057.historyLocationQuery---requestObject={}", requestObject);
        // 参数校验
        if (!validateRequestParams(ret, requestObject)) {
            ret.setCode(Constant.SUCCESS);
            request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
            return ret;
        }
        String url = supplierConfig.getUrl() + supplierConfig.getHistoryLocationPath();

        String token = stringRedisTemplate.boundValueOps(CommonConstant.REDIS_KEY_LOCATION_TOKEN).get();
        if (StringUtils.isBlank(token)) {
            token = tokenService.getAuthToken();
        }
        token = "JWT " + token;
        // 请求数据源
        String responseContext = "";
        try {
            RequestBody requestBody = new FormBody.Builder()
                    .add("tel", requestObject.getMobile())
                    .add("start_end", requestObject.getStartTime() + "~" + requestObject.getEndTime())
                    .build();
            responseContext = OkHttpUtil.doPost(url, requestBody, outTime, token);
            log.info("supplier10000057-historyLocationQuery-responseContext:{}", UnicodeUtil.unicodeToString(responseContext));
        } catch (IOException ioe) {
            log.info("supplier10000057.historyLocationQuery接口-SocketTimeoutException：", ioe);
            ErrorUtils.captureException(ioe);
            ret.setCode(Constant.REQUEST_TIMEOUT);
            return ret;
        }

        // 解析返回结果
        OriginalCommonResponseObject responseObject = JSON.toJavaObject(JSON.parseObject(responseContext),
                OriginalCommonResponseObject.class);
        ret.setIsCharge(Constant.IS_NOT_CHARGE);
        if (responseObject != null) {
            ret.setCode(Constant.SUCCESS);
            upstreamCode = responseObject.getCode();
            if (responseObject.getCode().equals(CommonConstant.REQUEST_SUCCESS)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_1192);
                ret.setResultBody(responseObject.getData());
                ret.setResultDesc(Constant.RETURN_MESSAGE_139);
            } else {
                ret.setResultCode(Constant.JK_RETURN_CODE_1193);
                ret.setResultBody(responseObject.getMsg());
                ret.setResultDesc(Constant.RETURN_MESSAGE_140);
            }
        } else {
            ret.setCode(Constant.FAIL);
        }
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        return ret;
    }

    private boolean validateRequestParams(ChannelTypeHandleResponseObject ret,
                                          GetHistoryLocationTaskRequestObject requestObject) {
        Pattern numberPattern = Pattern.compile(CommonConstant.NUMBER_REGEX);
        if (!validateParamNullValue(requestObject)) {
            ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
            ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            return false;
        } else if (StringUtils.isBlank(requestObject.getName())) {
            ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            ret.setResultDesc(Constant.INVALID_PARAMETER);
            ret.setResultBody(Constant.INVALID_PARAMETER);
            return false;
        } else if ((requestObject.getLimit() != null && !numberPattern.matcher(requestObject.getLimit().toString()).matches())
                || (requestObject.getPage() != null && !numberPattern.matcher(requestObject.getPage().toString()).matches())) {
            ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            ret.setResultBody(Constant.INVALID_PARAMETER);
            ret.setResultDesc(Constant.INVALID_PARAMETER);
            return false;
        } else {
            return true;
        }
    }

    private boolean validateRequestParams(ChannelTypeHandleResponseObject ret,
                                          CreateHistoryLocationTaskRequestObject requestObject) {
        Pattern datePattern = Pattern.compile(CommonConstant.DATE_REGEX);
        if (!validateParamNullValue(requestObject)) {
            ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
            ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            return false;
        } else if (StringUtils.isBlank(requestObject.getName())
                || requestObject.getName().length() < 2 || requestObject.getName().length() > 12) {
            ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            ret.setResultDesc(Constant.INVALID_PARAMETER);
            ret.setResultBody(Constant.INVALID_PARAMETER);
            return false;
        } else if (StringUtils.isBlank(requestObject.getType())
                || (!requestObject.getType().equals("1") && !requestObject.getType().equals("2"))) {
            ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            ret.setResultBody(Constant.INVALID_PARAMETER);
            ret.setResultDesc(Constant.INVALID_PARAMETER);
            return false;
        } else if (StringUtils.isBlank(requestObject.getStartTime())
                || !datePattern.matcher(requestObject.getStartTime()).matches()) {
            ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            ret.setResultBody(Constant.INVALID_PARAMETER);
            ret.setResultDesc(Constant.INVALID_PARAMETER);
            return false;
        } else if (StringUtils.isBlank(requestObject.getEndTime())
                || !datePattern.matcher(requestObject.getEndTime()).matches()) {
            ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            ret.setResultBody(Constant.INVALID_PARAMETER);
            ret.setResultDesc(Constant.INVALID_PARAMETER);
            return false;
        } else if (validateDates(requestObject.getStartTime(), requestObject.getEndTime())) {
            ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            ret.setResultBody(Constant.INVALID_PARAMETER);
            ret.setResultDesc(Constant.INVALID_PARAMETER);
            return false;
        } else if (StringUtils.isBlank(requestObject.getTimespan())
                || Integer.parseInt(requestObject.getTimespan()) < 15) {
            ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            ret.setResultBody(Constant.INVALID_PARAMETER);
            ret.setResultDesc(Constant.INVALID_PARAMETER);
            return false;
        } else if (StringUtils.isBlank(requestObject.getMobile()) ||
                !PatternTools.checkResult(Constant.PATTERN_MOBILE_REGEX, requestObject.getMobile())) {
            ret.setResultCode(Constant.JK_MOBILE_FORMAT_ERROR_CODE);
            ret.setResultDesc(Constant.JK_MOBILE_FORMAT_ERROR);
            ret.setResultBody(Constant.JK_MOBILE_FORMAT_ERROR);
            return false;
        } else {
            return true;
        }
    }

    private boolean validateRequestParams(ChannelTypeHandleResponseObject ret,
                                          HistoryLocationQueryRequestObject requestObject) {
        Pattern datePattern = Pattern.compile(CommonConstant.DATE_REGEX);
        if (!validateParamNullValue(requestObject)) {
            ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
            ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            return false;
        } else if (StringUtils.isBlank(requestObject.getStartTime())
                || !datePattern.matcher(requestObject.getStartTime()).matches()) {
            ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            ret.setResultBody(Constant.INVALID_PARAMETER);
            ret.setResultDesc(Constant.INVALID_PARAMETER);
            return false;
        } else if (StringUtils.isBlank(requestObject.getEndTime())
                || !datePattern.matcher(requestObject.getEndTime()).matches()) {
            ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            ret.setResultBody(Constant.INVALID_PARAMETER);
            ret.setResultDesc(Constant.INVALID_PARAMETER);
            return false;
        } else if (validateDates(requestObject.getStartTime(), requestObject.getEndTime())) {
            ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            ret.setResultBody(Constant.INVALID_PARAMETER);
            ret.setResultDesc(Constant.INVALID_PARAMETER);
            return false;
        } else if (StringUtils.isBlank(requestObject.getMobile()) ||
                !PatternTools.checkResult(Constant.PATTERN_MOBILE_REGEX, requestObject.getMobile())) {
            ret.setResultCode(Constant.JK_MOBILE_FORMAT_ERROR_CODE);
            ret.setResultDesc(Constant.JK_MOBILE_FORMAT_ERROR);
            ret.setResultBody(Constant.JK_MOBILE_FORMAT_ERROR);
            return false;
        } else {
            return true;
        }
    }

    private boolean validateRequestParams(ChannelTypeHandleResponseObject ret,
                                          DeleteHistoryLocationTaskRequestObject requestObject) {
        if (!validateParamNullValue(requestObject)) {
            ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
            ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            return false;
        } else if (StringUtils.isBlank(requestObject.getTid())) {
            ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            ret.setResultDesc(Constant.INVALID_PARAMETER);
            ret.setResultBody(Constant.INVALID_PARAMETER);
            return false;
        } else {
            return true;
        }
    }

    private boolean validateRequestParams(ChannelTypeHandleResponseObject ret,
                                          UpdateHistoryLocationTaskRequestObject requestObject) {
        if (!validateParamNullValue(requestObject)) {
            ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
            ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            return false;
        } else if (StringUtils.isBlank(requestObject.getTid())) {
            ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            ret.setResultDesc(Constant.INVALID_PARAMETER);
            ret.setResultBody(Constant.INVALID_PARAMETER);
            return false;
        } else if (StringUtils.isBlank(requestObject.getStatus())
                || (!requestObject.getStatus().equals("true") && !requestObject.getStatus().equals("false"))) {
            ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            ret.setResultBody(Constant.INVALID_PARAMETER);
            ret.setResultDesc(Constant.INVALID_PARAMETER);
            return false;
        } else {
            return true;
        }
    }

    private boolean validateParamNullValue(Object jsonResolveObject) {
        ValidatorFactory vf = Validation.buildDefaultValidatorFactory();
        Validator validator = vf.getValidator();
        Set<ConstraintViolation<Object>> set = validator.validate(jsonResolveObject);
        for (ConstraintViolation<Object> con : set) {
            if (StringUtils.isNotBlank(con.getMessage())) {
                return false;
            }
        }
        return true;
    }

    private boolean validateDates(String startTime, String endTime) {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd hh:mm:ss");
        try {
            Date start = sdf.parse(startTime);
            Date end = sdf.parse(endTime);
            long difference = end.getTime() - start.getTime();
            return difference >= 604800000;
        } catch (Exception e) {
            e.printStackTrace();
            return false;
        }
    }
}
