package info.aspirecn.iov.sjjh.supplier10000057.service.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import info.aspirecn.iov.sjjh.commons.lang.ChannelTypeHandleResponseObject;
import info.aspirecn.iov.sjjh.commons.lang.Constant;
import info.aspirecn.iov.sjjh.commons.lang.PatternTools;
import info.aspirecn.iov.sjjh.supplier10000057.config.SupplierConfig;
import info.aspirecn.iov.sjjh.supplier10000057.constant.CommonConstant;
import info.aspirecn.iov.sjjh.supplier10000057.model.OriginalCommonResponseObject;
import info.aspirecn.iov.sjjh.supplier10000057.model.RealTimeLocationQueryRequestObject;
import info.aspirecn.iov.sjjh.supplier10000057.service.RealTimeLocationService;
import info.aspirecn.iov.sjjh.supplier10000057.service.TokenService;
import info.aspirecn.iov.sjjh.supplier10000057.util.OkHttpUtil;
import info.aspirecn.iov.sjjh.supplier10000057.util.UnicodeUtil;
import info.aspirecn.rdc.aspirecloud.node.except.utils.ErrorUtils;
import lombok.extern.slf4j.Slf4j;
import okhttp3.FormBody;
import okhttp3.RequestBody;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import java.io.IOException;
import java.util.Set;

/**
 * @author xusonglin
 * @version V1.0
 **/
@Service
@Slf4j
public class RealTimeLocationServiceImpl implements RealTimeLocationService {
    @Autowired
    SupplierConfig supplierConfig;
    @Autowired
    StringRedisTemplate stringRedisTemplate;
    @Autowired
    TokenService tokenService;

    @Override
    public ChannelTypeHandleResponseObject realTimeLocationQuery(HttpServletRequest request, String customBody, int outTime) {
        ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
        ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
        String upstreamCode = "" + Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        if (outTime <= CommonConstant.PARA_ZERO) {
            outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
        }
        log.info("supplier10000057.realTimeLocationQuery---customBody={},outTime={}", customBody, outTime);
        RealTimeLocationQueryRequestObject requestObject = JSON.toJavaObject(JSON.parseObject(customBody),
                RealTimeLocationQueryRequestObject.class);
        log.info("supplier10000057.realTimeLocationQuery---requestObject={}", requestObject);
        // 参数校验
        if (!validateRequestParams(ret, requestObject)) {
            ret.setCode(Constant.SUCCESS);
            request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
            return ret;
        }
        String url = supplierConfig.getUrl() + supplierConfig.getLocationPath();

        String token = stringRedisTemplate.boundValueOps(CommonConstant.REDIS_KEY_LOCATION_TOKEN).get();
        if (StringUtils.isBlank(token)) {
            token = tokenService.getAuthToken();
        }
        token = "JWT " + token;
        // 请求数据源
        String responseContext = "";
        try {
            RequestBody requestBody = new FormBody.Builder()
                    .add("tel", "[" + requestObject.getMobile() + "]")
                    .build();
            responseContext = OkHttpUtil.doPost(url, requestBody, outTime, token);
            log.info("supplier10000057-realTimeLocationQuery-responseContext:{}", UnicodeUtil.unicodeToString(responseContext));
        } catch (IOException ioe) {
            log.info("supplier10000057.realTimeLocationQuery接口-SocketTimeoutException：", ioe);
            ErrorUtils.captureException(ioe);
            ret.setCode(Constant.REQUEST_TIMEOUT);
            return ret;
        }

        // 解析返回结果
        OriginalCommonResponseObject responseObject = JSON.toJavaObject(JSON.parseObject(responseContext),
                OriginalCommonResponseObject.class);
        if (responseObject != null) {
            ret.setCode(Constant.SUCCESS);
            upstreamCode = responseObject.getCode();
            if (responseObject.getCode().equals(CommonConstant.REQUEST_SUCCESS)) {
                JSONObject result = new JSONObject();
                result.put("data", responseObject.getData());
                ret.setResultBody(result);
                ret.setResultCode(Constant.JK_RETURN_CODE_1192);
                ret.setResultDesc(CommonConstant.SUCCESS_MESSAGE);
                ret.setIsCharge(Constant.IS_CHARGE);
            } else {
                Object errorData = responseObject.getErrdata()[0];
                JSONObject error = JSON.parseObject(String.valueOf(errorData));
                String errorMessage = error.getString(requestObject.getMobile());
                ret.setResultCode(Constant.JK_RETURN_CODE_1193);
                ret.setResultBody(errorMessage);
                ret.setResultDesc(errorMessage);
            }
        } else {
            ret.setCode(Constant.FAIL);
        }
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        return ret;
    }

    private boolean validateRequestParams(ChannelTypeHandleResponseObject ret,
                                          RealTimeLocationQueryRequestObject requestObject) {
        if (!validateParamNullValue(requestObject)) {
            ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
            ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            return false;
        } else if (StringUtils.isBlank(requestObject.getMobile()) ||
                !PatternTools.checkResult(Constant.PATTERN_MOBILE_REGEX, requestObject.getMobile())) {
            ret.setResultCode(Constant.JK_MOBILE_FORMAT_ERROR_CODE);
            ret.setResultDesc(Constant.JK_MOBILE_FORMAT_ERROR);
            ret.setResultBody(Constant.JK_MOBILE_FORMAT_ERROR);
            return false;
        } else {
            return true;
        }
    }

    private boolean validateParamNullValue(Object jsonResolveObject) {
        ValidatorFactory vf = Validation.buildDefaultValidatorFactory();
        Validator validator = vf.getValidator();
        Set<ConstraintViolation<Object>> set = validator.validate(jsonResolveObject);
        for (ConstraintViolation<Object> con : set) {
            if (StringUtils.isNotBlank(con.getMessage())) {
                return false;
            }
        }
        return true;
    }
}
