package info.aspirecn.iov.sjjh.supplier10000057.service.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import info.aspirecn.iov.sjjh.supplier10000057.config.SupplierConfig;
import info.aspirecn.iov.sjjh.supplier10000057.constant.CommonConstant;
import info.aspirecn.iov.sjjh.supplier10000057.model.TokenRequestObject;
import info.aspirecn.iov.sjjh.supplier10000057.service.TokenService;
import info.aspirecn.iov.sjjh.supplier10000057.util.OkHttpUtil;
import info.aspirecn.iov.sjjh.supplier10000057.util.UnicodeUtil;
import info.aspirecn.rdc.aspirecloud.node.except.utils.ErrorUtils;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Service;

import java.io.IOException;

/**
 * @author xusonglin
 * @version V1.0
 **/
@Service
@Slf4j
public class TokenServiceImpl implements TokenService {
    @Autowired
    SupplierConfig supplierConfig;
    @Autowired
    StringRedisTemplate stringRedisTemplate;

    @Override
    public String getAuthToken() {
        TokenRequestObject tokenRequestObject = new TokenRequestObject();
        tokenRequestObject.setUsername(supplierConfig.getUsername());
        tokenRequestObject.setPassword(supplierConfig.getPassword());
        String url = supplierConfig.getUrl() + supplierConfig.getTokenPath();
        String responseContext = "";
        try {
            responseContext = OkHttpUtil.doPost(url, JSON.toJSONString(tokenRequestObject), CommonConstant.GET_TOKEN_OUT_TIME);
            log.info("supplier10000057-getAuthToken-responseContext:{}", UnicodeUtil.unicodeToString(responseContext));
        } catch (IOException ioe) {
            log.info("supplier10000057-getAuthToken-IOException：", ioe);
            ErrorUtils.captureException(ioe);
        }

        if (StringUtils.isNotBlank(responseContext) && responseContext.contains("token")) {
            JSONObject responseObject = JSON.parseObject(responseContext);
            String token = responseObject.getString("token");
            stringRedisTemplate.boundValueOps(CommonConstant.REDIS_KEY_LOCATION_TOKEN).set(token);
            return token;
        } else {
            return "";
        }
    }
}
